.. _catalog:

***************************
Catalog (`gammapy.catalog`)
***************************

.. currentmodule:: gammapy.catalog

Introduction
============

`gammapy.catalog` contains tools to create and analyse source catalogs,
as well as high-level interfaces to the most relevant catalog for gamma-ray astronomy.

TODO: give one example, e.g. how to reproduce a log(N)-log(S) plot from a Fermi catalog paper.

Getting Started
===============

TODO: give some more example.

Reference/API
=============

.. automodapi:: gammapy.catalog
    :no-inheritance-diagram:
